Enum optional::OptionBool
[−]
[src]
pub enum OptionBool {
SomeTrue,
SomeFalse,
None,
}The OptionBool type, a space-efficient Option
Variants
SomeTrueSome(true)
SomeFalseSome(false)
NoneNone
Methods
impl OptionBool[src]
pub fn some(b: bool) -> Self[src]
Create a SomeTrue for true, SomeFalse for false
pub fn none() -> Self[src]
pub fn is_some(&self) -> bool[src]
Returns true if the option is a Some value.
Examples
assert!(OptionBool::SomeTrue.is_some()); assert!(OptionBool::SomeFalse.is_some()); assert!(!OptionBool::None.is_some());
pub fn is_none(&self) -> bool[src]
Returns true if the option is a Some value.
Examples
assert!(!OptionBool::SomeTrue.is_none()); assert!(!OptionBool::SomeFalse.is_none()); assert!(OptionBool::None.is_none());
pub fn expect(&self, msg: &str) -> bool[src]
Unwraps the contained bool, panics on None with given message.
Panics
if self is None
Examples
For SomeTrue/SomeFalse, the corresponding bool is returned.
assert!(OptionBool::SomeTrue.expect("FAIL")); assert!(!OptionBool::SomeFalse.expect("FAIL"));
On None, it panics with the given message.
OptionBool::None.expect("FAIL"); // panics with FAIL
pub fn unwrap(&self) -> bool[src]
Unwraps the contained bool, panics on None.
Panics
if self is None
Examples
For SomeTrue/SomeFalse, the corresponding bool is returned.
assert!(OptionBool::SomeTrue.unwrap()); assert!(!OptionBool::SomeFalse.unwrap());
On None, it panics with "unwrap called on None"
OptionBool::None.unwrap(); // panics
pub fn unwrap_or(&self, def: bool) -> bool[src]
Returns the contained bool or a default.
Examples
assert!(OptionBool::SomeTrue.unwrap_or(false)); assert!(!OptionBool::SomeFalse.unwrap_or(true)); assert!(OptionBool::None.unwrap_or(true)); assert!(!OptionBool::None.unwrap_or(false));
pub fn unwrap_or_else<F>(self, f: F) -> bool where
F: FnOnce() -> bool, [src]
F: FnOnce() -> bool,
Returns the contained bool or a computed default.
Examples
assert!(OptionBool::SomeTrue.unwrap_or_else(|| false)); assert!(!OptionBool::SomeFalse.unwrap_or_else(|| panic!())); assert!(OptionBool::None.unwrap_or_else(|| true));
pub fn map<U, F>(self, f: F) -> Option<U> where
F: FnOnce(bool) -> U, [src]
F: FnOnce(bool) -> U,
Maps an OptionBool to an Option<U> by applying the function
over the contained bool.
Note that there is also map_bool(..) which works
similarly, but returns another OptionBool.
Examples
Convert the contained bool to a Yes/No message
assert_eq!(Some("Yes"), OptionBool::SomeTrue.map( |b| if b { "Yes" } else { "No" }));
pub fn map_bool<F>(self, f: F) -> OptionBool where
F: FnOnce(bool) -> bool, [src]
F: FnOnce(bool) -> bool,
Maps an OptionBool to another OptionBool by applying the
function over the contained bool.
Note that there is also map(..) which works
similarly, but returns an Option<bool>.
Examples
Invert the contained bool
assert_eq!(OptionBool::SomeTrue, OptionBool::SomeFalse.map_bool(|b| !b));
pub fn map_or<U, F>(self, default: U, f: F) -> U where
F: FnOnce(bool) -> U, [src]
F: FnOnce(bool) -> U,
Maps a value to a U by applying the function or return a
default U.
Examples
Map to a string (as per the daily wtf's boolean definition):
assert_eq!("True", OptionBool::SomeTrue.map_or("FileNotFound", |b| if b { "True" } else { "False" }));
pub fn map_or_else<U, D, F>(self, default: D, f: F) -> U where
D: FnOnce() -> U,
F: FnOnce(bool) -> U, [src]
D: FnOnce() -> U,
F: FnOnce(bool) -> U,
Maps a value to a U by applying the function or return a
computed default.
Examples
assert_eq!("True", OptionBool::SomeTrue.map_or_else(|| "FileNotFound", |b| if b { "True" } else { "False" }));
pub fn ok_or<E>(self, err: E) -> Result<bool, E>[src]
Transforms the OptionBool into a Result<bool, E>, mapping
SomeX to Ok(X) and None to Err(err).
Examples
assert_eq!(OptionBool::SomeTrue.ok_or("Ouch"), Ok(true)); assert_eq!(OptionBool::None.ok_or("Ouch"), Err("Ouch"));
pub fn ok_or_else<E, F>(self, err: F) -> Result<bool, E> where
F: FnOnce() -> E, [src]
F: FnOnce() -> E,
Transforms the OptionBool into a Result<bool, E>, mapping SomeX to
Ok(X) and None to a calculated Err(err).
Examples
assert_eq!(OptionBool::SomeTrue.ok_or_else(|| something_expensive()), Ok(true)); assert_eq!(OptionBool::None.ok_or_else(|| "Ouch"), Err("Ouch"));
pub fn and<U>(self, optb: Option<U>) -> Option<U>[src]
Returns None if the option is None, otherwise returns optb.
Examples
assert_eq!(Some(1), OptionBool::SomeTrue.and(Some(1))); assert_eq!(None, OptionBool::None.and(Some(1))); let actual : Option<u8> = None; assert_eq!(None, OptionBool::SomeTrue.and(actual));
pub fn and_bool(self, optb: OptionBool) -> OptionBool[src]
Returns None if the option is None, otherwise returns optb.
Examples
assert_eq!(OptionBool::SomeTrue, OptionBool::SomeFalse.and_bool(OptionBool::SomeTrue)); assert_eq!(OptionBool::None, OptionBool::None.and_bool(OptionBool::SomeFalse)); assert_eq!(OptionBool::None, OptionBool::SomeTrue.and_bool(OptionBool::None));
pub fn and_then<U, F>(self, f: F) -> Option<U> where
F: FnOnce(bool) -> Option<U>, [src]
F: FnOnce(bool) -> Option<U>,
returns None if the OptionBool is None, otherwise calls f with
the boolean value and returns the result as an Option<U>
Note that there is also and_then_bool(..)
which works similarly, but returns another OptionBool.
Examples
assert_eq!(None, OptionBool::SomeFalse.and_then( |x| if x { Some(true) } else { None }));
pub fn and_then_bool<F>(self, f: F) -> OptionBool where
F: FnOnce(bool) -> OptionBool, [src]
F: FnOnce(bool) -> OptionBool,
returns None if the OptionBool is None, otherwise calls f with
the boolean value and returns the result as an OptionBool
Note that there is also and_then(..) which works
similarly, but returns an Option<bool>.
Examples
assert_eq!(OptionBool::None, OptionBool::SomeFalse.and_then_bool( |x| if x { OptionBool::SomeTrue } else { OptionBool::None }));
pub fn or(self, optb: Option<bool>) -> Option<bool>[src]
Returns this as Option unless this is None, in which case returns
optb.
Examples
assert_eq!(Some(false), OptionBool::SomeFalse.or(Some(true))); assert_eq!(Some(true), OptionBool::None.or(Some(true))); assert_eq!(None, OptionBool::None.or(None));
pub fn or_bool(self, optb: OptionBool) -> OptionBool[src]
Returns this as Option unless this is None, in which case returns
optb.
Examples
assert_eq!(OptionBool::SomeFalse, OptionBool::SomeFalse.or_bool(OptionBool::SomeTrue)); assert_eq!(OptionBool::SomeTrue, OptionBool::None.or_bool(OptionBool::SomeTrue)); assert_eq!(OptionBool::None, OptionBool::None.or_bool(OptionBool::None));
pub fn or_else<F>(self, f: F) -> Option<bool> where
F: FnOnce() -> Option<bool>, [src]
F: FnOnce() -> Option<bool>,
Returns this as Option unless this is None, in which case use the
supplied function to calculate the result.
Note that there is also or_else_bool(..)
which works similarly, but returns another OptionBool.
Examples
assert_eq!(Some(false), OptionBool::SomeFalse.or_else(|| Some(true))); assert_eq!(Some(true), OptionBool::None.or_else(|| Some(true))); assert_eq!(None, OptionBool::None.or_else(|| None));
pub fn or_else_bool<F>(self, f: F) -> OptionBool where
F: FnOnce() -> OptionBool, [src]
F: FnOnce() -> OptionBool,
Returns this as Option unless this is None, in which case use the
supplied function to calculate the result.
Note that there is also or_else(..) which works
similarly, but returns an Option<bool>.
Examples
assert_eq!(OptionBool::SomeFalse, OptionBool::SomeFalse.or_else_bool(|| OptionBool::SomeTrue)); assert_eq!(OptionBool::SomeTrue, OptionBool::None.or_else_bool(|| OptionBool::SomeTrue)); assert_eq!(OptionBool::None, OptionBool::None.or_else_bool(|| OptionBool::None));
ⓘImportant traits for Iter<'a, T>pub fn iter(&self) -> Iter<bool>[src]
return an iterator over all contained (that is zero or one) values.
Examples
assert_eq!(None, OptionBool::None.iter().next()); assert_eq!(Some(&true), OptionBool::SomeTrue.iter().next());
pub fn as_slice(self) -> &'static [bool][src]
return a possibly empty slice with the contained value, if any.
Examples
assert_eq!(&[true], OptionBool::SomeTrue.as_slice()); assert!(OptionBool::None.as_slice().is_empty());
pub fn take(&mut self) -> Option<bool>[src]
Takes the value out of the OptionBool and returns ist as
Option<bool>, changing self to None.
Note that there is also take_bool(..) which
works similarly, but returns an OptionBool.
Examples
let mut x = OptionBool::some(true); assert_eq!(Some(true), x.take()); assert_eq!(OptionBool::None, x);
pub fn take_bool(&mut self) -> OptionBool[src]
Methods from Deref<Target = Option<bool>>
pub fn is_some(&self) -> bool1.0.0[src]
Returns true if the option is a Some value.
Examples
let x: Option<u32> = Some(2); assert_eq!(x.is_some(), true); let x: Option<u32> = None; assert_eq!(x.is_some(), false);
pub fn is_none(&self) -> bool1.0.0[src]
Returns true if the option is a None value.
Examples
let x: Option<u32> = Some(2); assert_eq!(x.is_none(), false); let x: Option<u32> = None; assert_eq!(x.is_none(), true);
pub fn as_ref(&self) -> Option<&T>1.0.0[src]
Converts from Option<T> to Option<&T>.
Examples
Convert an Option<String> into an Option<usize>, preserving the original.
The map method takes the self argument by value, consuming the original,
so this technique uses as_ref to first take an Option to a reference
to the value inside the original.
let text: Option<String> = Some("Hello, world!".to_string()); // First, cast `Option<String>` to `Option<&String>` with `as_ref`, // then consume *that* with `map`, leaving `text` on the stack. let text_length: Option<usize> = text.as_ref().map(|s| s.len()); println!("still can print text: {:?}", text);
ⓘImportant traits for Iter<'a, A>pub fn iter(&self) -> Iter<T>1.0.0[src]
Returns an iterator over the possibly contained value.
Examples
let x = Some(4); assert_eq!(x.iter().next(), Some(&4)); let x: Option<u32> = None; assert_eq!(x.iter().next(), None);